@@ -14,24 +14,26 @@
 
 int
 main(int argc, char **argv){
-        int fd, cons;
+	int fd, cons;
 	struct { char fn, subarg; } arg;
 
+#ifndef __klibc__
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(PACKAGE_NAME, LOCALEDIR);
+	textdomain(PACKAGE_NAME);
+#endif
 
 	if (argc == 2)
 		cons = atoi(argv[1]);
 	else
 		cons = 0;	/* current console */
 
-        fd = getfd(NULL);
+	fd = getfd(NULL);
 	arg.fn = 11;		/* redirect kernel messages */
 	arg.subarg = cons;	/* to specified console */
-        if (ioctl(fd, TIOCLINUX, &arg)) {
-                perror("TIOCLINUX");
-                exit(1);
-        }
-        return 0;
+	if (ioctl(fd, TIOCLINUX, &arg)) {
+		perror("TIOCLINUX");
+		exit(1);
+	}
+	return 0;
 }
